@@ -5,6 +5,6 @@ if [ -z "$JAVACMD" ] ; then
 	JAVACMD=java
 fi
 
-exec $JAVACMD $JAVA_OPTS -jar /usr/share/geogebra/geogebra.jar "$@"
+exec $JAVACMD -Xms32m -Xmx512m $JAVA_OPTS -jar /usr/share/geogebra/geogebra.jar "$@"
 	
 
